@@ -213,8 +213,8 @@ eog_application_init_accelerators (GtkApplication *application)
 		"win.set-wallpaper",	"<Ctrl>F8", NULL,
 		"win.manual",		"F1", NULL,
 
-		"win.go-previous",	"Left", "BackSpace", NULL,
-		"win.go-next",		"Right", NULL,
+		"win.go-previous",	"BackSpace", NULL,
+		/* "win.go-next",	NULL,*/
 		"win.go-first",		"<Alt>Home", "Home", NULL,
 		"win.go-last",		"<Alt>End", "End", NULL,
 		"win.go-random",	"<Ctrl>m", NULL,
@@ -236,6 +236,7 @@ eog_application_init_accelerators (GtkApplication *application)
 		"win.view-slideshow",	"F5", NULL,
 		"win.toggle-zoom-fit",	"F", NULL,
 		"win.toggle-gear-menu",	"F10", NULL,
+		"win.pause-slideshow",	"p", NULL,
 
 		NULL /* Terminating NULL */
 	};
