@@ -613,13 +613,15 @@ press_inside_image_area (EogPrintPreview *preview,
 			 guint y)
 {
 	EogPrintPreviewPrivate *priv;
+	const gint xs = (gint) x;
+	const gint ys = (gint) y;
 	gint x0, y0;
 
 	priv = preview->priv;
 	get_current_image_coordinates (preview, &x0, &y0);
 
-	if (x >= x0 &&  y >= y0 &&
-	    x <= x0 + priv->r_width && y <= y0 + priv->r_height)
+	if (xs >= x0 &&  ys >= y0 &&
+	    xs <= x0 + priv->r_width && ys <= y0 + priv->r_height)
 		return TRUE;
 
 	return FALSE;
@@ -744,6 +746,8 @@ button_press_event_cb (GtkWidget *widget,
 	case 1:
 		preview->priv->grabbed = press_inside_image_area (preview, event->x, event->y);
 		break;
+	default:
+		break;
 	}
 
 	if (preview->priv->grabbed) {
@@ -768,7 +772,9 @@ button_release_event_cb (GtkWidget *widget,
 		preview->priv->r_dx = 0;
 		preview->priv->r_dy = 0;
 		gtk_widget_queue_draw (GTK_WIDGET (preview));
-
+		break;
+	default:
+		break;
 	}
 	return FALSE;
 }
@@ -801,6 +807,8 @@ key_press_event_cb (GtkWidget   *widget,
 		property = "image-y-align";
 		delta = 0.01;
 		break;
+	default:
+		break;
 	}
 
 	if (delta != 0) {
